%-----Script1 Calculations-----
% clear all;

%---------------------------------- 
%Aggregate Z, E, UG, UE, S, and Y into a one world region.

%Load EXIOPOL SIOT data
load('SIOT_2region_pxp_v11.mat');

%Define arrays for Z, E, UG, S, and UE from imported SIOT data
Z_IOIO = siot(1:129, 1:129);
Z_IOROW = siot(1:129, 130:258);
Z_ROWIO = siot(130:258, 1:129);
Z_ROWROW = siot(130:258, 130:258);
E_IO = siot(292:627, 1:129);
E_ROW = siot(292:627, 130:258);
UG_IO = siot(628:683, 1:129);
UG_ROW = siot(628:683, 130:258);
Y_IOIO = siot(1:129, 259:265);
Y_IOROW = siot(1:129, 266:272);
Y_ROWIO = siot(130:258, 259:265);
Y_ROWROW = siot(130:258, 266:272);


%Calculate sizes of the imported matricies for use as indexes in for loops.
[Zi_max, Zj_max] = size(Z_IOIO);
[Ei_max, Ej_max] = size(E_IO);
[UGi_max, UGj_max] = size(UG_IO);
[UEi_max, UEj_max] = size(UE_IO);
[Si_max, Sj_max] = size(S_IO);
[Yi_max, Yj_max] = size(Y_IOIO);

%Aggregate Z into a two quadrants, and then into one region.
for i = 1:Zi_max
    for j = 1:Zj_max
        Z_IO(i,j) = Z_IOIO(i,j) + Z_IOROW(i,j);
        Z_ROW(i,j) = Z_ROWIO(i,j) + Z_ROWROW(i,j);
    end
end
for i = 1:Zi_max
    for j = 1:Zj_max
        Z_One(i,j) = Z_IO(i,j) + Z_ROW(i,j);
    end
end

%Aggregate E into one region.
for i = 1:Ei_max
    for j = 1:Ej_max
        E_One(i,j) = E_IO(i,j) + E_ROW(i,j);
    end
end

%Aggregate UG into one region.
for i = 1:UGi_max
    for j = 1:UGj_max
        UG_One(i,j) = UG_IO(i,j) + UG_ROW(i,j);
    end
end

%Aggregate Y into a two quadrants, and then into one region.
for i = 1:Yi_max
    for j = 1:Yj_max
        Y_IO(i,j) = Y_IOIO(i,j) + Y_IOROW(i,j);
        Y_ROW(i,j) = Y_ROWIO(i,j) + Y_ROWROW(i,j);
    end
end
for i = 1:Yi_max
    for j = 1:Yj_max
        Y_One(i,j) = Y_IO(i,j) + Y_ROW(i,j);
    end
end

%---------------------------------- 
%UG currently lacks any consumption of biofuels. To fix this according to
%IEA WEO 2000 biofuels figures, we will manually change specific "Biogasol"
%values for the 6 transport related sectors.
UG_One(56,101) = 3240;
UG_One(56,102) = 307267;
UG_One(56,103) = 28928;
UG_One(56,104) = 278;
UG_One(56,105) = 70620;
UG_One(56,106) = 3643;



%---------------------------------- 
%Aggregate the 129 products of Z into the 6 IEA categories (PG, OE, I, T, B, O). 
%!! consider moving this
IEA_Z_ctg_code = importdata('IEA_Z_ctg.xls'); %129 Z rows labeled with corresponding 6 IEA categories
IEA_ctg_code = importdata('IEA_ctg.xls');
Z_ctg = zeros(Zi_max,6);
for j = 1:Zj_max
    for n = 1:6
        if strcmp(IEA_ctg_code(n) ,IEA_Z_ctg_code(j)); 
            Z_ctg(:,n) = Z_ctg(:,n) + Z_One(:,j);
        end
    end
end



%---------------------------------- 
%Based on Z monetary breakdown of types of electricity for each of the 129
%products, we disaggregate the UG ELEC row into 6 additional UG physical
%electricity rows.

%Import Pcode vectors that correlate the UG energy products with the
%energy-related products in the Z matrix.
UG_Pcode = importdata('UG_Pcode.xls');
Z_Pcode = importdata('Z_Pcode.xls');
Z_Elec_Pcode = importdata('Z_Elec_Pcode.xls'); %24 Z energy-related Pcodes

Z_Elec_Mix = zeros(6,129);
Z_Elec_Sum = zeros(1,129);

for i = 1:Zi_max
    for n = 1:6
        if strcmp(Z_Elec_Pcode(n,1), Z_Pcode(i,1))
            Z_Elec_Sum(1,:) = Z_Elec_Sum(1,:) + Z_One(i,:);
        end
    end
end
        
for i = 1:Zi_max
    for n = 1:6
        if strcmp(Z_Elec_Pcode(n,1), Z_Pcode(i,1))
            Z_Elec_Mix(n,:) = Z_One(i,:) ./ Z_Elec_Sum(1,:);
        end
    end
end

%Apply the Z_Elec_Mix to disaggregate UG ELEC (row 40) into new electricity
%type rows that will be added to UG_One (rows 57:62)
UGi_max_elec = UGi_max + 6;
UG_One_Elec = UG_One;
UG_One_Elec(57:62,:) = zeros(6,129);
for i = 1:6
    UG_One_Elec(56+i,:) = Z_Elec_Mix(i,:) .* UG_One_Elec(40,:);
end


%-----------------------------------------
%Compare UG year 2000 data with the IEA 2000 data, by aggregating
%UG_One_Elec results (62x129) into a comparable format as IEA (17x6). 
%This is only used as a check.

%Aggreate the 56 UG fuels into the 17 energy categories defined by IEA, and
%then aggregate the 129 columns of products into the 6 IEA categories. 
IEA_UG_conv_code = importdata('IEA_UG_conv.xls'); %56 UG rows labeled with 17 IEA energy types
IEA_conv_code = importdata('IEA_conv.xls'); %17 IEA energy types
IEA_conv_max = size(IEA_conv_code);

IEA_UG_conv = zeros(17, UGj_max);
for i = 1:UGi_max_elec
    for n = 1:17
        if strcmp(IEA_conv_code(n), IEA_UG_conv_code(i)); 
            IEA_UG_conv(n,:) = IEA_UG_conv(n,:) + UG_One_Elec(i,:); 
        end
    end
end

IEA_PG_share = importdata('IEA_PG_share.xls');

%Aggregate IEA_UG_conv into the 6 IEA categories (IEA_UG_ctg)
IEA_UG_ctg = zeros(17, 6);
for j = 1:UGj_max
    for n = 1:6
        if strcmp(IEA_ctg_code(n), IEA_Z_ctg_code(j)); 
            IEA_UG_ctg(:,n) = IEA_UG_ctg(:,n) + IEA_UG_conv(:,j);
        end
    end
end

%NOTE: IEA_UG_conv and IEA_UG_ctg are double counting ELEC, since it has
%the total ELEC and the disaggregated.


%-----------------------------------------
%Import IEA magnitude and share matrices for 2000, 2009, NPS, CPS, 450.
IEA_mag = importdata('IEA_mag.xls'); %Note last 3 rows is Total, Heat, Elec.
IEA_share = importdata('IEA_share.xls');
IEA_mag(isnan(IEA_mag)) = 0;
IEA_share(isnan(IEA_share)) = 0;

%converting mtoe to TJ
IEA_mag_2000 = IEA_mag(:,1:6) .* (4.1868*10^4);
IEA_mag_2009 = IEA_mag(:,7:12) .* (4.1868*10^4);
IEA_mag_NPS = IEA_mag(:,13:18) .* (4.1868*10^4);
IEA_mag_CPS = IEA_mag(:,19:24) .* (4.1868*10^4);
IEA_mag_450 = IEA_mag(:,25:30) .* (4.1868*10^4);

IEA_share_2000 = IEA_share(:,1:6);
IEA_share_2009 = IEA_share(:,7:12);
IEA_share_NPS = IEA_share(:,13:18);
IEA_share_CPS = IEA_share(:,19:24);
IEA_share_450 = IEA_share(:,25:30);

%Summing up the columns of IEA_mag_2000 so that we can calculate what the
%magnitude of the IEA scenarios would be like in their respective energy
%mixes, but with no growth in energy use (total energy still sums up to year 2000
%energy, but with future energy mixes)
sum_share_2000 = sum(IEA_mag_2000(1:16,:));

%Calculate the change in share percentage to reach the mixes in future
%scenarios. These "d_share_XXX" factors will be multiplied with the
%monetary flows to get the new energy mixes.
Z_mag_2009 = IEA_share_2009 * diag(sum_share_2000);
d_share_2009 = Z_mag_2009 ./ IEA_mag_2000;
d_share_2009(isnan(d_share_2009)) = 0;

Z_mag_NPS = IEA_share_NPS * diag(sum_share_2000);
d_share_NPS = Z_mag_NPS ./ IEA_mag_2000;
d_share_NPS(isnan(d_share_NPS)) = 0;

Z_mag_CPS = IEA_share_CPS * diag(sum_share_2000);
d_share_CPS = Z_mag_CPS ./ IEA_mag_2000;
d_share_CPS(isnan(d_share_CPS)) = 0;

Z_mag_450 = IEA_share_450 * diag(sum_share_2000);
d_share_450 = Z_mag_450 ./ IEA_mag_2000;
d_share_450(isnan(d_share_450)) = 0;

%Calculate change in energy supply for future scenarios. This is used as a
%check, so if the sum total for the scenarios add up to 0, then it is correct.
d_mag_2009 = Z_mag_2009 - IEA_mag_2000;
d_mag_NPS = Z_mag_NPS - IEA_mag_2000;
d_mag_CPS = Z_mag_CPS - IEA_mag_2000;
d_mag_450 = Z_mag_450 - IEA_mag_2000;


%-----------------------------------------
%Using the d_share_XXX values (XXX represents scenarios), multiply with IEA_UG_conv to change the energy mix
%for the UG energy values for all 129 sectors. 
IEA_UG_2009 = zeros(17,UGj_max);
for j = 1:UGj_max
    for n = 1:6
        if strcmp(IEA_ctg_code(n) ,IEA_Z_ctg_code(j)); 
            IEA_UG_2009(:,j) = (d_share_2009(:,n))' * diag(IEA_UG_conv(:,j));
        end
    end
end

IEA_UG_NPS = zeros(17,UGj_max);
for j = 1:UGj_max
    for n = 1:6
        if strcmp(IEA_ctg_code(n) ,IEA_Z_ctg_code(j)); 
            IEA_UG_NPS(:,j) = (d_share_NPS(:,n))' * diag(IEA_UG_conv(:,j));
        end
    end
end

IEA_UG_CPS = zeros(17,UGj_max);
for j = 1:UGj_max
    for n = 1:6
        if strcmp(IEA_ctg_code(n) ,IEA_Z_ctg_code(j)); 
            IEA_UG_CPS(:,j) = (d_share_CPS(:,n))' * diag(IEA_UG_conv(:,j));
        end
    end
end

IEA_UG_450 = zeros(17,UGj_max);
for j = 1:UGj_max
    for n = 1:6
        if strcmp(IEA_ctg_code(n) ,IEA_Z_ctg_code(j)); 
            IEA_UG_450(:,j) = (d_share_450(:,n))' * diag(IEA_UG_conv(:,j));
        end
    end
end


%Setting row 17 (ELEC) of all these projections to 0, because it is already
%accounted for in the disaggregated electricity mix. But before this is
%done, we will save a copy of these projections including ELEC for future
%use.

%Keeping the electricity mixes for later
IEA_mag_2000_ELEC = IEA_mag_2000;
IEA_UG_2009_ELEC = IEA_UG_2009;
IEA_UG_NPS_ELEC = IEA_UG_NPS;
IEA_UG_CPS_ELEC = IEA_UG_CPS;
IEA_UG_450_ELEC = IEA_UG_450;

%Setting ELEC (row 17) to zero
IEA_mag_2000(17,:) = 0;
IEA_UG_2009(17,:) = 0;
IEA_UG_NPS(17,:) = 0;
IEA_UG_CPS(17,:) = 0;
IEA_UG_450(17,:) = 0;


%-----------------------------------------
%Calculate the prices per unit energy in EXIOPOL by dividing monetary flow
%by energy. 

Z_Energy_Pcode = importdata('Z_Energy_Pcode.xls');

UG_Pcode_conv = zeros(24, UGj_max);
for i = 1:UGi_max_elec
    for n = 1:24
        if strcmp(Z_Energy_Pcode(n), UG_Pcode(i)); 
            UG_Pcode_conv(n,:) = UG_Pcode_conv(n,:) + UG_One_Elec(i,:);
            if strcmp('p12',UG_Pcode(i));
                UG_Pcode_conv(14,:) = UG_Pcode_conv(14,:) + UG_One_Elec(i,:); %both mining and processing use UG_nuclear
            end
            if strcmp('p40.12',UG_Pcode(i));
                UG_Pcode_conv(22,:) = UG_Pcode_conv(22,:) + UG_One_Elec(i,:); %both transmission and distribution use UG_ELEC
            end
        end
    end
end

Z_Pcode_conv = zeros(24, Zj_max);
for i = 1:Zi_max
    for n = 1:24
        if strcmp(Z_Energy_Pcode(n), Z_Pcode(i)); 
            Z_Pcode_conv(n,:) = Z_Pcode_conv(n,:) + Z_One(i,:);
        end
    end
end

EnergyPrice_Z_UG = Z_Pcode_conv ./ UG_Pcode_conv;

% Final results are saved under 'script1_Data_v2.mat'
 
 
 
 
 
 
 
 
