%Code for aggregating Emissions by fuel by sector by countries into a one
%world region.

clear all;

%Need to run 'EXIOPOL_OneRegion_Aggregation_v12.m' script first
load('script1_Data_v2.mat');

%Import emissions by fuel by sector database (db.mat)
db = load('db.mat');
db_Values_max = size(db.dbvals);

%Import row indexes for pollutants, fuel type, and Z industry codes, along
%with max sizes of these indices.
PollutantCode = importdata('PollutantCode.xls');
FuelCode = importdata('FuelCode.xls');
Z_Icode = importdata('Z_Icode.xls');

Z_Icode_max = size(Z_Icode);
FuelCode_max = size(FuelCode);
PollutantCode_max = size(PollutantCode);


%Create a bridge matrix that indicates which pollutant each row in db.vals
%is represented. Similar matricies are created for FuelCode and Z_Icode.
%PollutantCode_matrix(696096x71)
PollutantCode_matrix = zeros(db_Values_max(1,1), PollutantCode_max(1,1));
for r = 1:db_Values_max(1,1)
    for i = 1:PollutantCode_max(1,1)
        if strcmp(db.dbtext(r,3),PollutantCode(i))
            PollutantCode_matrix(r,i) = 1;
        end
    end
end

FuelCode_matrix = zeros(db_Values_max(1,1), FuelCode_max(1,1));
for r = 1:db_Values_max(1,1)
    for i = 1:FuelCode_max(1,1)
        if strcmp(db.dbtext(r,5),FuelCode(i))
            FuelCode_matrix(r,i) = 1;
        end
    end
end

Z_Icode_matrix = zeros(db_Values_max(1,1), Z_Icode_max(1,1));
for r = 1:db_Values_max(1,1)
    for i = 1:Z_Icode_max(1,1)
        if strcmp(db.dbtext(r,2),Z_Icode(i))
            Z_Icode_matrix(r,i) = 1;
        end
    end
end


%Using the code matrices above, we can find the index row and column for
%each row, and temporarily store it as temp_A. We then use sort rows to
%order these indexes properly for all three dimensions: FuelCode, PollutantCode, and Z_Icode.
[FuelCode_indexRow, FuelCode_indexCol] = find(FuelCode_matrix);
temp_A = [FuelCode_indexRow, FuelCode_indexCol];
FuelCode_index = sortrows(temp_A,1);

[PollutantCode_indexRow, PollutantCode_indexCol] = find(PollutantCode_matrix);
temp_B = [PollutantCode_indexRow, PollutantCode_indexCol];
PollutantCode_index = sortrows(temp_B,1);

[Z_Icode_indexRow, Z_Icode_indexCol] = find(Z_Icode_matrix);
temp_C = [Z_Icode_indexRow, Z_Icode_indexCol];
Z_Icode_index = sortrows(temp_C,1);

%Create Emissions_index, which combines all three dimensions into 3
%columns.
Emissions_index = [FuelCode_index(:,2), Z_Icode_index(:,2), PollutantCode_index(:,2)];


%--------------------------------
% --To skip all steps above, run CalculationsData_v4.mat 
% load('CalculationsData_v4.mat')
% --Run db_One

%Sum up db.vals across all of the countries, such that when countries share
%the same FuelCode, Z_Icode, and PollutantCode, they get added together.
%db_One (67x129x71)
db_One = zeros(FuelCode_max(1,1), Z_Icode_max(1,1), PollutantCode_max(1,1));

for r = 1:db_Values_max(1,1)
	db_One(Emissions_index(r,1), Emissions_index(r,2), Emissions_index(r,3)) = db_One(Emissions_index(r,1), Emissions_index(r,2), Emissions_index(r,3)) + db.dbvals(r,1);
end

%Final results are saved under 'script2_Data_v1.mat'















