%Script 3 Calculations
clear all
load('script2_Data_v6.mat');  

%Initialize matricies
db_One_max = size(db_One);
Unit_Emission = zeros(UGi_max_elec, UGj_max, db_One_max(1,3));
UG_FuelCode = importdata('UG_FuelCode.xls');
db_One = db_One(:,1:129,:);


%-----------------------------------------
%Calculate Unit_Emissions by dividing emissions by UG.
%To divide by UG, invert UG only if non-zero to avoid errors.
for i = 1:UGi_max
    for j = 1:UGj_max
        if UG_One(i,j) ~= 0
            inv_UG_One(i,j) = 1 ./ UG_One(i,j);
        end
    end
end

%For sum total of emissions per sector, aggregate emissions in db_One across
%all fuels.
temp_D = sum(db_One,1);
for k = 1:71
    for j = 1:129
        E_db_One(k,j) = temp_D(1,j,k);
    end
end

%For all pollutants, divide db_One emission value by respetive UG value to
%get Unit_Emissions.
for r = 1:PollutantCode_max(1,1) %pollutant axis
    for i = 1:UGi_max_elec %fuel axis for UG
        for n = 1:FuelCode_max(1,1) %fuel axis for db
            if strcmp(UG_FuelCode(i,1), FuelCode(n,1))
                Unit_Emission(i,:,r) = db_One(n,:,r) .* inv_UG_One(i,:);
            end
        end
    end
end


%-----------------------------------------
%convert IEA_UG_XXX(17x129) scenarios into UG_XXX(56x129) using
%IEA_UG_conv_code reversed. Every product under a particular label (e.g.
%F_C) will grow by the corresponding IEA scenario percentage.

%invert only if non-zero for IEA_UG_conv
for i = 1:17
    for j = 1:129
        if IEA_UG_conv(i,j) ~= 0
            inv_IEA_UG_conv(i,j) = 1 ./ IEA_UG_conv(i,j);
        end
    end
end

%Determine the percentage breakdown of UG_One_Elec 62 fuels into the 17 IEA fuel
%categories (e.g. 1 IEA category for Coal as fuel is comprised of 4 
%different types of coal as defined by UG).
%Multiply these percent breakdowns by the scenario energy mixes IEA_UG_XXX_ELEC
%projections to disaggregate the IEA projections into the 62 UG categories.

%UG_XXX_temp is a temporary matrix that will later be corrected so that the
%the total UG for each sector remains the same.
for i = 1:UGi_max_elec
    for n = 1:IEA_conv_max
        if strcmp(IEA_UG_conv_code(i), IEA_conv(n)) 
            UG_2009_percent(i,:) = (UG_One_Elec(i,:) .* inv_IEA_UG_conv(n,:));
            UG_NPS_percent(i,:) = (UG_One_Elec(i,:) .* inv_IEA_UG_conv(n,:));
            UG_CPS_percent(i,:) = (UG_One_Elec(i,:) .* inv_IEA_UG_conv(n,:));
            UG_450_percent(i,:) = (UG_One_Elec(i,:) .* inv_IEA_UG_conv(n,:));
            
            UG_2009_temp(i,:) = IEA_UG_2009_ELEC(n,:) .* UG_2009_percent(i,:);
            UG_NPS_temp(i,:) = IEA_UG_NPS_ELEC(n,:) .* UG_NPS_percent(i,:);
            UG_CPS_temp(i,:) = IEA_UG_CPS_ELEC(n,:) .* UG_CPS_percent(i,:);
            UG_450_temp(i,:) = IEA_UG_450_ELEC(n,:) .* UG_450_percent(i,:);
        end
    end
end
  

%----------------------------------------
%Calculate UG_XXX, which takes UG_XXX_temp and scales it to match the total
%UG under each of the 129 sectors
UG_One_sum = zeros(1,129);
UG_2009_temp_sum = zeros(1,129);
UG_NPS_temp_sum = zeros(1,129);
UG_CPS_temp_sum = zeros(1,129);
UG_450_temp_sum = zeros(1,129);
UG_2009_temp_elec_sum = zeros(1,129);
UG_NPS_temp_elec_sum = zeros(1,129);
UG_CPS_temp_elec_sum = zeros(1,129);
UG_450_temp_elec_sum = zeros(1,129);

for j = 1:129
    for i = 1:56
        UG_One_sum(1,j) = UG_One_sum(1,j) + UG_One(i,j);
        UG_2009_temp_sum(1,j) = UG_2009_temp_sum(1,j) + UG_2009_temp(i,j);
        UG_NPS_temp_sum(1,j) = UG_NPS_temp_sum(1,j) + UG_NPS_temp(i,j);
        UG_CPS_temp_sum(1,j) = UG_CPS_temp_sum(1,j) + UG_CPS_temp(i,j);
        UG_450_temp_sum(1,j) = UG_450_temp_sum(1,j) + UG_450_temp(i,j); 
    end
end

%Calculate the percentage mix for 
for i = 1:56
    UG_2009_temp_percent(i,:) = UG_2009_temp(i,:) ./ UG_2009_temp_sum(1,:);
    UG_NPS_temp_percent(i,:) = UG_NPS_temp(i,:) ./ UG_NPS_temp_sum(1,:);
    UG_CPS_temp_percent(i,:) = UG_CPS_temp(i,:) ./ UG_CPS_temp_sum(1,:);
    UG_450_temp_percent(i,:) = UG_450_temp(i,:) ./ UG_450_temp_sum(1,:);

    UG_2009(i,:) = UG_2009_temp_percent(i,:) .* UG_One_sum(1,:);
    UG_NPS(i,:) = UG_NPS_temp_percent(i,:) .* UG_One_sum(1,:);
    UG_CPS(i,:) = UG_CPS_temp_percent(i,:) .* UG_One_sum(1,:);
    UG_450(i,:) = UG_450_temp_percent(i,:) .* UG_One_sum(1,:);
end

%Calculate the electricity breakdown, given the new electricity number for
%each of the 129 categories.
for i = 57:62
    UG_2009_temp_elec_sum(1,:) = UG_2009_temp_elec_sum(1,:) + UG_2009_temp(i,:);
    UG_NPS_temp_elec_sum(1,:) = UG_NPS_temp_elec_sum(1,:) + UG_NPS_temp(i,:);
    UG_CPS_temp_elec_sum(1,:) = UG_CPS_temp_elec_sum(1,:) + UG_CPS_temp(i,:);
    UG_450_temp_elec_sum(1,:) = UG_450_temp_elec_sum(1,:) + UG_450_temp(i,:);
end

for i = 57:62
    for j = 1:129
        if UG_2009_temp_elec_sum(1,j) ~= 0
            UG_2009(i,j) = UG_2009(40,j) * (UG_2009_temp(i,j) / UG_2009_temp_elec_sum(1,j));
        end
        if UG_NPS_temp_elec_sum(1,j) ~= 0
            UG_NPS(i,j) = UG_NPS(40,j) * (UG_NPS_temp(i,j) / UG_NPS_temp_elec_sum(1,j));
        end
        if UG_CPS_temp_elec_sum(1,j) ~= 0
            UG_CPS(i,j) = UG_CPS(40,j) * (UG_CPS_temp(i,j) / UG_CPS_temp_elec_sum(1,j));
        end
        if UG_450_temp_elec_sum(1,j) ~= 0
            UG_450(i,j) = UG_450(40,j) * (UG_450_temp(i,j) / UG_450_temp_elec_sum(1,j));
        end
    end
end

%To allow for energy efficiency, the sectors related to PG and OE in UG_XXX will be
%restored to the UG_XXX_temp numbers.
for j = 1:129
    if strcmp('PG',IEA_Z_ctg_code(j))
        UG_2009(:,j) = UG_2009_temp(:,j);
        UG_NPS(:,j) = UG_NPS_temp(:,j);
        UG_CPS(:,j) = UG_CPS_temp(:,j);
        UG_450(:,j) = UG_450_temp(:,j);
    elseif strcmp('OE',IEA_Z_ctg_code(j))
        UG_2009(:,j) = UG_2009_temp(:,j);
        UG_NPS(:,j) = UG_NPS_temp(:,j);
        UG_CPS(:,j) = UG_CPS_temp(:,j);
        UG_450(:,j) = UG_450_temp(:,j);        
    end
end


%-----------------------------------------
%d_UG_XXX = UG_XXX - UG_One (which is year 2000) in order to see the
%changes in each energy product for each industry.
d_UG_2009 = UG_2009 - UG_One_Elec;
d_UG_NPS = UG_NPS - UG_One_Elec;
d_UG_CPS = UG_CPS - UG_One_Elec;
d_UG_450 = UG_450 - UG_One_Elec;

%E_dUG_fuel_XXX = d_UG_XXX * Unit_Emission to get the corresponding change in
%emissions across all industries/fuels.
for r = 1:PollutantCode_max(1,1)
    for i = 1:UGi_max
        E_dUG_fuel_2009(i,:,r) = d_UG_2009(i,:) .* Unit_Emission(i,:,r);
        E_dUG_fuel_NPS(i,:,r) = d_UG_NPS(i,:) .* Unit_Emission(i,:,r);
        E_dUG_fuel_CPS(i,:,r) = d_UG_CPS(i,:) .* Unit_Emission(i,:,r);
        E_dUG_fuel_450(i,:,r) = d_UG_450(i,:) .* Unit_Emission(i,:,r);
    end
end

%Sum up the totals across all fuels for each pollutant under each industry
%to get E_dUG_total_XXX for each scenario.
E_dUG_total_2009 = sum(E_dUG_fuel_2009, 1);
E_dUG_total_NPS = sum(E_dUG_fuel_NPS, 1);
E_dUG_total_CPS = sum(E_dUG_fuel_CPS, 1);
E_dUG_total_450 = sum(E_dUG_fuel_450, 1);

%Convert 3 dimensional matrix E_dUG_total_XXX into 2 dimensional form,
%since the 3rd dimension was the fuel category that was previously summed
%up.
E_dUG_2009 = zeros(PollutantCode_max(1,1), UGj_max);
E_dUG_NPS = zeros(PollutantCode_max(1,1), UGj_max);
E_dUG_CPS = zeros(PollutantCode_max(1,1), UGj_max);
E_dUG_450 = zeros(PollutantCode_max(1,1), UGj_max);

for r = 1:PollutantCode_max(1,1)
    for j = 1:UGj_max
        E_dUG_2009(r,j) = E_dUG_total_2009(1,j,r);
        E_dUG_NPS(r,j) = E_dUG_total_NPS(1,j,r);
        E_dUG_CPS(r,j) = E_dUG_total_CPS(1,j,r);
        E_dUG_450(r,j) = E_dUG_total_450(1,j,r);
    end
end


%-----------------------------------------
%Aggregate E_One stressors (multiple CO2s into one) according to how
%stressors are defined in the characterisation matrix E_char. Aggregate
%E_dUG_XXX stressors also in the same manner.

%Correlate the pollutants from E_dUG_total_XXX to E_One (year 2000) by
%using the vector "E_UG_code".
E_char_index = importdata('E_char_index.xls');
E_One_index = importdata('E_One_index.xls');
E_db_index = importdata('E_db_index.xls');

%E_One based on EXIOPOL E table
E_One_sum = zeros(size(E_char_index,1),Ej_max);
for i = 1:size(E_char_index,1);
    for n = 1:size(E_One_index,1);
        if strcmp(E_One_index(n,1), E_char_index(i,1))
            E_One_sum(i,:) = E_One_sum(i,:) + E_One(n,:);
        end
    end
end

%E_db_One based on EmissionsByFuel sum. This will be used instead of E_One.
E_db_One_sum = zeros(size(E_char_index,1), Ej_max);
for i = 1:size(E_char_index,1);
    for n = 1:size(E_db_index,1);
        if strcmp(E_db_index(n,1), E_char_index(i,1))
            E_db_One_sum(i,:) = E_db_One(n,:);
        end
    end
end

E_dUG_2009_sum = zeros(size(E_char_index,1),Ej_max);
E_dUG_NPS_sum = zeros(size(E_char_index,1),Ej_max);
E_dUG_CPS_sum = zeros(size(E_char_index,1),Ej_max);
E_dUG_450_sum = zeros(size(E_char_index,1),Ej_max);
for i = 1:size(E_char_index,1);
    for n = 1:size(E_db_index,1);
        if strcmp(E_db_index(n,1), E_char_index(i,1))
            E_dUG_2009_sum(i,:) = E_dUG_2009_sum(i,:) + E_dUG_2009(n,:);
            E_dUG_NPS_sum(i,:) = E_dUG_NPS_sum(i,:) + E_dUG_NPS(n,:);
            E_dUG_CPS_sum(i,:) = E_dUG_CPS_sum(i,:) + E_dUG_CPS(n,:);
            E_dUG_450_sum(i,:) = E_dUG_450_sum(i,:) + E_dUG_450(n,:);
        end
    end
end


%-----------------------------------------
%E_XXX = E_db_One + E_dUG_total_XXX to get the new emissions for each pollutant and
%sector. Note that E_db_One is used instead of the one from EXIOPOL, E_One
E_2009 = E_db_One_sum + E_dUG_2009_sum;
E_NPS = E_db_One_sum + E_dUG_NPS_sum;
E_CPS = E_db_One_sum + E_dUG_CPS_sum;
E_450 = E_db_One_sum + E_dUG_450_sum;


%-----------------------------------------
%convert physical energy values UG_XXX(62x129) into monetary Z_XXX(24x129)
%using "EnergyPrice_Z_UG".
Z_Energy_Pcode = importdata('Z_Energy_Pcode.xls');

d_Z_2009 = zeros(24,129);
d_Z_NPS = zeros(24,129);
d_Z_CPS = zeros(24,129);
d_Z_450 = zeros(24,129);

for i = 1:UGi_max_elec
    for n = 1:24
        if strcmp(Z_Energy_Pcode(n,1), UG_Pcode(i,1))
            d_Z_2009(n,:) = d_Z_2009(n,:) + (d_UG_2009(i,:) .* EnergyPrice_Z_UG(n,:));
            d_Z_NPS(n,:) = d_Z_NPS(n,:) + (d_UG_NPS(i,:) .* EnergyPrice_Z_UG(n,:));
            d_Z_CPS(n,:) = d_Z_CPS(n,:) + (d_UG_CPS(i,:) .* EnergyPrice_Z_UG(n,:));
            d_Z_450(n,:) = d_Z_450(n,:) + (d_UG_450(i,:) .* EnergyPrice_Z_UG(n,:));
        end
    end
end

Z_2009 = Z_One;
Z_NPS = Z_One;
Z_CPS = Z_One;
Z_450 = Z_One;

for i = 1:129
    for n = 1:24
        if strcmp(Z_Energy_Pcode(n,1), Z_Pcode(i,1))
            Z_2009(i,:) = Z_One(i,:) + d_Z_2009(n,:);
            Z_NPS(i,:) = Z_One(i,:) + d_Z_NPS(n,:);
            Z_CPS(i,:) = Z_One(i,:) + d_Z_CPS(n,:);
            Z_450(i,:) = Z_One(i,:) + d_Z_450(n,:);
        end
    end
end


%----------------------------------------------
%Aggregate 129 products into 13 broad categories
Z_Icode_agg_few = importdata('Z_Icode_agg_few.xls');
Z_Icode_agg = importdata('Z_Icode_agg.xls');

%initialize matricies
temp_2000_agg = zeros(13,129);
temp_2009_agg = zeros(13,129);
temp_NPS_agg = zeros(13,129);
temp_CPS_agg = zeros(13,129);
temp_450_agg = zeros(13,129);

Z_2000_agg = zeros(13,13);
Z_2009_agg = zeros(13,13);
Z_NPS_agg = zeros(13,13);
Z_CPS_agg = zeros(13,13);
Z_450_agg = zeros(13,13);

Y_One_agg = zeros(13,7);

E_2000_agg = zeros(28,13);
E_2009_agg = zeros(28,13);
E_NPS_agg = zeros(28,13);
E_CPS_agg = zeros(28,13);
E_450_agg = zeros(28,13);

%aggregate 129 into 13
for i = 1:129
    for n = 1:13
        if strcmp(Z_Icode_agg(i,1), Z_Icode_agg_few(n,1));
            %aggregate the rows in a temporary matrix
            temp_2000_agg(n,:) = temp_2000_agg(n,:) + Z_One(i,:);
            temp_2009_agg(n,:) = temp_2009_agg(n,:) + Z_2009(i,:);
            temp_NPS_agg(n,:) = temp_NPS_agg(n,:) + Z_NPS(i,:);
            temp_CPS_agg(n,:) = temp_CPS_agg(n,:) + Z_CPS(i,:);
            temp_450_agg(n,:) = temp_450_agg(n,:) + Z_450(i,:);
      
            %aggregate rows of Y_One
            Y_One_agg(n,:) = Y_One_agg(n,:) + Y_One(i,:);
            
            %aggregate columns of E
            E_2000_agg(:,n) = E_2000_agg(:,n) + E_db_One_sum(:,i);
            E_2009_agg(:,n) = E_2009_agg(:,n) + E_2009(:,i);
            E_NPS_agg(:,n) = E_NPS_agg(:,n) + E_NPS(:,i);
            E_CPS_agg(:,n) = E_CPS_agg(:,n) + E_CPS(:,i);
            E_450_agg(:,n) = E_450_agg(:,n) + E_450(:,i);          
        end
    end
end

%aggregate columns of temporary Z matrix
for i = 1:129
    for n = 1:13
        if strcmp(Z_Icode_agg(i,1), Z_Icode_agg_few(n,1));
            Z_2000_agg(:,n) = Z_2000_agg(:,n) + temp_2000_agg(:,i);
            Z_2009_agg(:,n) = Z_2009_agg(:,n) + temp_2009_agg(:,i);
            Z_NPS_agg(:,n) = Z_NPS_agg(:,n) + temp_NPS_agg(:,i);
            Z_CPS_agg(:,n) = Z_CPS_agg(:,n) + temp_CPS_agg(:,i);
            Z_450_agg(:,n) = Z_450_agg(:,n) + temp_450_agg(:,i);
        end
    end
end


%----------------------------------------------
%Calculate X by summing up the intermediate demand Z, and the final demand
%Y. Note that final demand Y never changes between scenarios.
X_One = sum(Z_One,2) + sum(Y_One,2);
X_2009 = sum(Z_2009,2) + sum(Y_One,2);
X_NPS = sum(Z_NPS,2) + sum(Y_One,2);
X_CPS = sum(Z_CPS,2) + sum(Y_One,2);
X_450 = sum(Z_450,2) + sum(Y_One,2);

X_2000_agg = sum(Z_2000_agg,2) + sum(Y_One_agg,2);
X_2009_agg = sum(Z_2009_agg,2) + sum(Y_One_agg,2);
X_NPS_agg = sum(Z_NPS_agg,2) + sum(Y_One_agg,2);
X_CPS_agg = sum(Z_CPS_agg,2) + sum(Y_One_agg,2);
X_450_agg = sum(Z_450_agg,2) + sum(Y_One_agg,2);


%calculate the A_One and A_XXX
A_One = Z_One * inv(diag(X_One));
A_2009 = Z_2009 * inv(diag(X_2009));
A_NPS = Z_NPS * inv(diag(X_NPS));
A_CPS = Z_CPS * inv(diag(X_CPS));
A_450 = Z_450 * inv(diag(X_450));

A_2000_agg = Z_2000_agg * inv(diag(X_2000_agg));
A_2009_agg = Z_2009_agg * inv(diag(X_2009_agg));
A_NPS_agg = Z_NPS_agg * inv(diag(X_NPS_agg));
A_CPS_agg = Z_CPS_agg * inv(diag(X_CPS_agg));
A_450_agg = Z_450_agg * inv(diag(X_450_agg));


%calculate the total emissions by summing across all sectors.
E_total_2000 = sum(E_db_One_sum,2);
E_total_2009 = sum(E_2009, 2);
E_total_NPS = sum(E_NPS, 2);
E_total_CPS = sum(E_CPS, 2);
E_total_450 = sum(E_450, 2);

E_total_2000_agg = sum(E_2000_agg,2);
E_total_2009_agg = sum(E_2009_agg, 2);
E_total_NPS_agg = sum(E_NPS_agg, 2);
E_total_CPS_agg = sum(E_CPS_agg, 2);
E_total_450_agg = sum(E_450_agg, 2);


%calculate emissions intensity matrix for E_int_XXX
E_int_One = E_db_One_sum * inv(diag(X_One));
E_int_2009 = E_2009 * inv(diag(X_2009));
E_int_NPS = E_NPS * inv(diag(X_NPS));
E_int_CPS = E_CPS * inv(diag(X_CPS));
E_int_450 = E_450 * inv(diag(X_450));

E_int_2000_agg = E_2000_agg * inv(diag(X_2000_agg));
E_int_2009_agg = E_2009_agg * inv(diag(X_2009_agg));
E_int_NPS_agg = E_NPS_agg * inv(diag(X_NPS_agg));
E_int_CPS_agg = E_CPS_agg * inv(diag(X_CPS_agg));
E_int_450_agg = E_450_agg * inv(diag(X_450_agg));


%calculate direct impacts with characterisation matrix.
C = importdata('Characterisation.xls');


%-------------------------------------------------
%calculate total economy wide direct impact
D_total_2000 = C' * E_total_2000;
D_total_2009 = C' * E_total_2009;
D_total_NPS = C' * E_total_NPS;
D_total_CPS = C' * E_total_CPS;
D_total_450 = C' * E_total_450;

D_dir_flow_2000_agg = C' * E_2000_agg;
D_dir_flow_2009_agg = C' * E_2009_agg;
D_dir_flow_NPS_agg = C' * E_NPS_agg;
D_dir_flow_CPS_agg = C' * E_CPS_agg;
D_dir_flow_450_agg = C' * E_450_agg;


%calculate direct intensity impacts
D_dir_int_2000 = C' * E_db_One_sum * inv(diag(X_One));
D_dir_int_2009 = C' * E_2009 * inv(diag(X_2009));
D_dir_int_NPS = C' * E_NPS * inv(diag(X_NPS));
D_dir_int_CPS = C' * E_CPS * inv(diag(X_CPS));
D_dir_int_450 = C' * E_450 * inv(diag(X_450));

D_dir_int_2000_agg = C' * E_2000_agg * inv(diag(X_2000_agg));
D_dir_int_2009_agg = C' * E_2009_agg * inv(diag(X_2009_agg));
D_dir_int_NPS_agg = C' * E_NPS_agg * inv(diag(X_NPS_agg));
D_dir_int_CPS_agg = C' * E_CPS_agg * inv(diag(X_CPS_agg));
D_dir_int_450_agg = C' * E_450_agg * inv(diag(X_450_agg));

%Calculate the direct UG energy usage.
UG_dir_int_2000 = UG_One * inv(diag(X_One));
UG_dir_int_2009 = UG_2009 * inv(diag(X_2009));
UG_dir_int_NPS = UG_NPS * inv(diag(X_NPS));
UG_dir_int_CPS = UG_CPS * inv(diag(X_CPS));
UG_dir_int_450 = UG_450 * inv(diag(X_450));

UG_dir_int_2000_sum = zeros(1,129);
UG_dir_int_2009_sum = zeros(1,129);
UG_dir_int_NPS_sum = zeros(1,129);
UG_dir_int_CPS_sum = zeros(1,129);
UG_dir_int_450_sum = zeros(1,129);

%Sum up all direct energy use of each column, except for the disaggregated
%electricity in rows 57-62, as it is already reprsented in row 40 in
%aggregated total.
for i = 1:56
    UG_dir_int_2000_sum(1,:) = UG_dir_int_2000_sum(1,:) + UG_dir_int_2000(i,:);
    UG_dir_int_2009_sum(1,:) = UG_dir_int_2009_sum(1,:) + UG_dir_int_2009(i,:);
    UG_dir_int_NPS_sum(1,:) = UG_dir_int_NPS_sum(1,:) + UG_dir_int_NPS(i,:);
    UG_dir_int_CPS_sum(1,:) = UG_dir_int_CPS_sum(1,:) + UG_dir_int_CPS(i,:);
    UG_dir_int_450_sum(1,:) = UG_dir_int_450_sum(1,:) + UG_dir_int_450(i,:);
end

%-------------------------------------------------

%calculate the total life cycle intensity impacts (direct and indirect)
I = eye(129);
I_agg = eye(13);

D_lc_int_2000 = C' * E_int_One * inv(I - A_One);
D_lc_int_2009 = C' * E_int_2009 * inv(I - A_2009);
D_lc_int_NPS = C' * E_int_NPS * inv(I - A_NPS);
D_lc_int_CPS = C' * E_int_CPS * inv(I - A_CPS);
D_lc_int_450 = C' * E_int_450 * inv(I - A_450);

D_lc_int_2000_agg = C' * E_int_2000_agg * inv(I_agg - A_2000_agg);
D_lc_int_2009_agg = C' * E_int_2009_agg * inv(I_agg - A_2009_agg);
D_lc_int_NPS_agg = C' * E_int_NPS_agg * inv(I_agg - A_NPS_agg);
D_lc_int_CPS_agg = C' * E_int_CPS_agg * inv(I_agg - A_CPS_agg);
D_lc_int_450_agg = C' * E_int_450_agg * inv(I_agg - A_450_agg);

%calculate the life cycle energy usage of each sector.
UG_lc_int_2000 = UG_dir_int_2000 * inv(I - A_One);
UG_lc_int_2009 = UG_dir_int_2009 * inv(I - A_2009);
UG_lc_int_NPS = UG_dir_int_CPS * inv(I - A_NPS);
UG_lc_int_CPS = UG_dir_int_NPS * inv(I - A_CPS);
UG_lc_int_450 = UG_dir_int_450 * inv(I - A_450);

UG_lc_int_2000_sum = zeros(1,129);
UG_lc_int_2009_sum = zeros(1,129);
UG_lc_int_NPS_sum = zeros(1,129);
UG_lc_int_CPS_sum = zeros(1,129);
UG_lc_int_450_sum = zeros(1,129);


%Sum up all lc energy use of each column, except for the disaggregated
%electricity in rows 57-62, as it is already reprsented in row 40 in
%aggregated total.
for i = 1:56
    UG_lc_int_2000_sum(1,:) = UG_lc_int_2000_sum(1,:) + UG_lc_int_2000(i,:);
    UG_lc_int_2009_sum(1,:) = UG_lc_int_2009_sum(1,:) + UG_lc_int_2009(i,:);
    UG_lc_int_NPS_sum(1,:) = UG_lc_int_NPS_sum(1,:) + UG_lc_int_NPS(i,:);
    UG_lc_int_CPS_sum(1,:) = UG_lc_int_CPS_sum(1,:) + UG_lc_int_CPS(i,:);
    UG_lc_int_450_sum(1,:) = UG_lc_int_450_sum(1,:) + UG_lc_int_450(i,:);
end
        
D_lc_flow_2000_agg = D_lc_int_2000_agg * diag(X_2000_agg);
%D_lc_flow_2000_agg = D_dir_flow_2000_agg * inv(I_agg - A_2000_agg);


%---------------------------------
%Aggregate UG_One_elec and UG_450 into 17 IEA fuel types
IEA_UG_2000_temp = zeros(17,129);
IEA_UG_450_temp = zeros(17,129);
for i = 1:UGi_max_elec
    for n = 1:17
        if strcmp(IEA_conv_code(n), IEA_UG_conv_code(i)); 
            IEA_UG_2000_temp(n,:) = IEA_UG_2000_temp(n,:) + UG_One_Elec(i,:); 
            IEA_UG_450_temp(n,:) = IEA_UG_450_temp(n,:) + UG_450(i,:);
        end
    end
end

%Aggregate IEA_UG_conv into 13 sectors. Do the same for IEA_UG_450.
IEA_UG_2000_agg = zeros(17,13);
IEA_UG_450_agg = zeros(17,13);
for i = 1:129
    for n = 1:13
        if strcmp(Z_Icode_agg(i,1), Z_Icode_agg_few(n,1));
            IEA_UG_2000_agg(:,n) = IEA_UG_2000_agg(:,n) + IEA_UG_2000_temp(:,i);
            IEA_UG_450_agg(:,n) = IEA_UG_450_agg(:,n) + IEA_UG_450_temp(:,i);
        end
    end
end

%Calculate the fraction of energy sectors as a proportion of X. Aggregate
%into sectors. Keep in flows.
Z_Energy_2000 = zeros(129,1);
Z_Energy_2000_agg = zeros(13,1);
for i = 1:129
    for n = 1:24
        for j = 1:129
            if strcmp(Z_Pcode(j,1), Z_Energy_Pcode(n,1))
                Z_Energy_2000(i,1) = Z_Energy_2000(i,1) + Z_One(i,j);
            end
        end
    end
end
      
for i = 1:129
    for n = 1:13
        if strcmp(Z_Icode_agg(i,1), Z_Icode_agg_few(n,1));
            Z_Energy_2000_agg(n,1) = Z_Energy_2000_agg(n,1) + Z_Energy_2000(i,1);
        end
    end
end

Energy_Percent_agg = Z_Energy_2000_agg ./ X_2000_agg;


%---------------------------------
%CHECK #1 on calculations
E_dUG_test_450 = E_dUG_fuel_450(:,:,6);
Unit_Emission_test = Unit_Emission(:,:,6);
db_One_test = db_One(:,:,6);

%Check between E_One_sum CO2 and E_db_One_sum.
B_check = E_db_One(6,:);
C02_check = E_One_sum(4,:);
